.. imprint: a program for creating documents from data and content templates

.. Copyright (C) 2019  Joseph R. Fox-Rabinovitz <jfoxrabinovitz at gmail dot com>

.. This program is free software: you can redistribute it and/or modify
.. it under the terms of the GNU Affero General Public License as
.. published by the Free Software Foundation, either version 3 of the
.. License, or (at your option) any later version.

.. This program is distributed in the hope that it will be useful,
.. but WITHOUT ANY WARRANTY; without even the implied warranty of
.. MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
.. GNU Affero General Public License for more details.

.. Author: Joseph Fox-Rabinovitz <jfoxrabinovitz at gmail dot com>
.. Version: 13 Apr 2019: Initial Coding


.. _reference:

=========
Reference
=========

This part of the documentation is the specifcation of the various components and
interfaces of Imprint. For examples and clearer usage instructions, consult one
of the pages in the :doc:`/tutorials/tutorials` section.

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :name: reference-toc

   configuration
   keywords
   xml_spec
   plugin_api
   tag_api
   programs
   logging
   internal_api
